@@ -7,7 +7,7 @@
  *                                                                         *
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
- * Functions    : MdcCheckECAT6()         - Check for ECAT 6.4 format      * 
+ * Functions    : MdcCheckECAT6()         - Check for ECAT 6.4 format      *
  *                MdcReadECAT6()          - Read ECAT 6.4 file             *
  *                MdcWriteECAT6()         - Write ECAT 6.4 file            *
  *                MdcGetSliceLocation()   - Get slice location             *
@@ -115,7 +115,7 @@ static Int16 MdcEcatSystemTypes[MDC_MAX_ECATSYSTEMTYPES]=
                             F U N C T I O N S
 ****************************************************************************/
 int MdcCheckECAT6(FILEINFO *fi)
-{ 
+{
   Mdc_Main_header mh;
   int i;
 
@@ -173,12 +173,12 @@ const char *MdcReadECAT6(FILEINFO *fi)
   }
 */
 
-  if (MDC_INFO || MDC_INFO_DB) { 
+  if (MDC_INFO || MDC_INFO_DB) {
 
     MdcPrntScrn("Main Header (%d bytes)\n",MH_64_SIZE);
     MdcPrintLine('-',MDC_HALF_LENGTH);
- 
-    MdcPrntScrn("Original Filename        : "); 
+
+    MdcPrntScrn("Original Filename        : ");
        MdcPrintStr(mh.original_file_name);
     MdcPrntScrn("Software Version         : %d\n",mh.sw_version);
     MdcPrntScrn("Data Type                : %d ",mh.data_type);
@@ -188,7 +188,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("System Type              : %d\n",mh.system_type);
     MdcPrntScrn("File Type                : %d ",mh.file_type);
-    if ((mh.file_type > -1) && (mh.file_type < 5)) 
+    if ((mh.file_type > -1) && (mh.file_type < 5))
       MdcPrntScrn("(= %s)\n",MdcEcatFileTypes[mh.file_type]);
     else
       MdcPrntScrn("(= Unknown)\n");
@@ -201,7 +201,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     MdcPrntScrn("          - Second       : %d\n",mh.scan_start_second);
     MdcPrntScrn("Isotope Code             : "); MdcPrintStr(mh.isotope_code);
     MdcPrntScrn("Isotope Halflife         : %f [sec]\n",mh.isotope_halflife);
-    MdcPrntScrn("Radiopharmaceutical      : "); 
+    MdcPrntScrn("Radiopharmaceutical      : ");
       MdcPrintStr(mh.radiopharmaceutical);
     MdcPrntScrn("Gantry Tilt              : %f [degrees]\n",mh.gantry_tilt);
     MdcPrntScrn("Gantry Rotation          : %f [degrees]\n"
@@ -222,20 +222,20 @@ const char *MdcReadECAT6(FILEINFO *fi)
     if ((mh.calibration_units > -1) && (mh.calibration_units < 12))
       MdcPrntScrn("(= %s)\n"
                     ,MdcEcatQuantificationUnits[mh.calibration_units]);
-    else 
+    else
       MdcPrntScrn("(= Unknown)\n");
     MdcPrntScrn("Compression Code         : %d\n",mh.compression_code);
     MdcPrntScrn("Study Name               : "); MdcPrintStr(mh.study_name);
     MdcPrntScrn("Patient Id               : "); MdcPrintStr(mh.patient_id);
     MdcPrntScrn("Patient Name             : "); MdcPrintStr(mh.patient_name);
-    MdcPrntScrn("Patient Sex              : "); MdcPrintChar(mh.patient_sex);  
+    MdcPrntScrn("Patient Sex              : "); MdcPrintChar(mh.patient_sex);
     MdcPrntScrn("\n");
     MdcPrntScrn("Patient Age              : "); MdcPrintStr(mh.patient_age);
     MdcPrntScrn("Patient Height           : ");
        MdcPrintStr(mh.patient_height);
     MdcPrntScrn("Patient Weight           : ");
        MdcPrintStr(mh.patient_weight);
-    MdcPrntScrn("Patient Dexterity        : "); 
+    MdcPrntScrn("Patient Dexterity        : ");
        MdcPrintChar(mh.patient_dexterity);
     MdcPrntScrn("\n");
     MdcPrntScrn("Physician Name           : ");
@@ -261,9 +261,9 @@ const char *MdcReadECAT6(FILEINFO *fi)
     MdcPrntScrn("Bed Offset[%02d]           : %f [cm]\n",i+1
                                                            ,mh.bed_offset[i]);
     MdcPrntScrn("Plane Separation         : %f [cm]\n",mh.plane_separation);
-    MdcPrntScrn("Lower Scatter Treshold   : %d [KeV]\n",mh.lwr_sctr_thres);
-    MdcPrntScrn("Lower True Treshold      : %d [KeV]\n",mh.lwr_true_thres);
-    MdcPrntScrn("Upper True Treshold      : %d [KeV]\n",mh.upr_true_thres);
+    MdcPrntScrn("Lower Scatter Threshold  : %d [KeV]\n",mh.lwr_sctr_thres);
+    MdcPrntScrn("Lower True Threshold     : %d [KeV]\n",mh.lwr_true_thres);
+    MdcPrntScrn("Upper True Threshold     : %d [KeV]\n",mh.upr_true_thres);
     MdcPrntScrn("Collimator               : %6.0f\n",mh.collimator);
     MdcPrntScrn("User Process Code        : ");
        MdcPrintStr(mh.user_process_code);
@@ -273,10 +273,10 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
   if (MDC_INFO_DB) return(NULL); /* just needed db info */
 
-  if ((mh.file_type!=MDC_ECAT6_SCAN_FILE)  && 
+  if ((mh.file_type!=MDC_ECAT6_SCAN_FILE)  &&
       (mh.file_type!=MDC_ECAT6_IMAGE_FILE) &&
-      (mh.file_type!=MDC_ECAT6_ATTN_FILE)  && 
-      (mh.file_type!=MDC_ECAT6_NORM_FILE) ) 
+      (mh.file_type!=MDC_ECAT6_ATTN_FILE)  &&
+      (mh.file_type!=MDC_ECAT6_NORM_FILE) )
     return("ECAT6 Unsupported file type");
 
   if (mh.num_frames  <= 0 ) mh.num_frames  = 1;
@@ -308,7 +308,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
     axial_width = mh.plane_separation * (float)fi->dim[3];
     if ((axial_width - bed_offset) >= 1.0) {
-      MdcPrntWarn("ECAT6 Bed overlaps unsupported"); 
+      MdcPrntWarn("ECAT6 Bed overlaps unsupported");
     }
   }
 
@@ -316,23 +316,23 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
   if (number == 0) return("ECAT6 No valid images specified");
 
-  /* fill in orientation information */ 
+  /* fill in orientation information */
   fi->pat_slice_orient = MDC_SUPINE_HEADFIRST_TRANSAXIAL; /* default! */
   str = MdcGetStrPatPos(fi->pat_slice_orient);
   MdcStringCopy(fi->pat_pos,str,strlen(str));
 
   if ( (strncmp(mh.user_process_code,"COR",10)==0) ||
        (strncmp(mh.user_process_code,"SAG",10)==0)) {
-    /* CORONAL SLICES  or SAGITTAL SLICES 
+    /* CORONAL SLICES  or SAGITTAL SLICES
        The images Ecat 6.4 software writes are useless:
        128x128 images with the small coronal/sagittal slice in it ...
        This means their pixel_xsize & pixel_ysize doesn't quite
-       fit the real world dimensions any more !! 
-       Therefore we don't even try to attempt writing the proper 
+       fit the real world dimensions any more !!
+       Therefore we don't even try to attempt writing the proper
        orientation information.
      */
   }else{
-    /* "TRA" or nothing 
+    /* "TRA" or nothing
        TRANSAXIAL SLICES (Transverse)
        Writing the proper orientation information
        See man-page `m-acr.4' for more info (!)
@@ -354,30 +354,30 @@ const char *MdcReadECAT6(FILEINFO *fi)
   fi->study_time_minute= mh.scan_start_minute;
   fi->study_time_second= mh.scan_start_second;
 
-  if ((mh.file_type==MDC_ECAT6_SCAN_FILE) || 
+  if ((mh.file_type==MDC_ECAT6_SCAN_FILE) ||
       (mh.file_type==MDC_ECAT6_IMAGE_FILE)) {
     switch (mh.acquisition_type) {
-      case MDC_ECAT6_ACQTYPE_UNKNOWN : 
+      case MDC_ECAT6_ACQTYPE_UNKNOWN :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_BLANK : 
+      case MDC_ECAT6_ACQTYPE_BLANK :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_TRANSMISSION : 
+      case MDC_ECAT6_ACQTYPE_TRANSMISSION :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      case MDC_ECAT6_ACQTYPE_STATIC_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_STATIC_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      case MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_DYNAMIC; break;
-      case MDC_ECAT6_ACQTYPE_GATED_EMISSION : 
+      case MDC_ECAT6_ACQTYPE_GATED_EMISSION :
           fi->acquisition_type = MDC_ACQUISITION_GSPECT;  break;
-      case MDC_ECAT6_ACQTYPE_TRANSMISSION_RECT : 
+      case MDC_ECAT6_ACQTYPE_TRANSMISSION_RECT :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
-      case MDC_ECAT6_ACQTYPE_EMISSION_RECT : 
+      case MDC_ECAT6_ACQTYPE_EMISSION_RECT :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
       case MDC_ECAT6_ACQTYPE_WHOLE_BODY_TRANSM :
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN; break;
       case MDC_ECAT6_ACQTYPE_WHOLE_BODY_STATIC :
           fi->acquisition_type = MDC_ACQUISITION_TOMO;    break;
-      default: 
+      default:
           fi->acquisition_type = MDC_ACQUISITION_UNKNOWN;
     }
   }else{
@@ -434,11 +434,11 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
       case MDC_ANATOMICAL: /* anatomical */
           bed = fi->dim[6]; /* one based */
-          if (fi->dim[4] > 1) { 
+          if (fi->dim[4] > 1) {
             mdc_plane_sort(matrix_list, num_matrices);
           }else{
             mdc_anatomical_sort(matrix_list, num_matrices, &mh, bed);
-          } 
+          }
           break;
       case MDC_BYFRAME   : /* by frame   */
           mdc_matnum_sort(matrix_list, num_matrices);
@@ -489,7 +489,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         switch (ssh.smoothing) {
           case 0: MdcPrntScrn("(= Not Smoothed)\n"); break;
           case 1: MdcPrntScrn("(= 9x9 Smoothing)\n"); break;
-         default: MdcPrntScrn("(= Unknown)\n"); 
+         default: MdcPrntScrn("(= Unknown)\n");
         }
         MdcPrntScrn("Processing Code     : %d\n",ssh.processing_code);
         MdcPrntScrn("Sample Distance     : %f [cm]\n",ssh.sample_distance);
@@ -506,7 +506,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         MdcPrntScrn("Total Multiples     : %d\n",ssh.multiples);
         MdcPrntScrn("Total Net Trues     : %d (Prompts - Random)\n"
                                       ,ssh.net_trues);
-        for (i=0; i<16; i++) 
+        for (i=0; i<16; i++)
         MdcPrntScrn("Corrected   Singles [%2d] : %f\n",i+1
                                                          ,ssh.cor_singles[i]);
         for (i=0; i<16; i++)
@@ -527,7 +527,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
         for (i=0; i<8; i++) MdcPrntScrn("Phy_Planes [%d]          : %d\n",i+1
                                                          ,ssh.phy_planes[i]);
        }
- 
+
        /* fill in DYNAMIC_DATA struct */
        if ((dd != NULL) && (plane == (fi->dim[3]/2))) {
          /* take values from a plane halfway */
@@ -549,7 +549,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
        id->quant_scale = ssh.scale_factor;
 
        id->pixel_xsize = id->pixel_ysize = ssh.sample_distance * 10.;/* mm */
-       data_type = ssh.data_type; 
+       data_type = ssh.data_type;
        switch( data_type ) {
          case  BYTE_TYPE:  id->bits = 8; id->type = BIT8_U; break;
          case  M68K_I2  :
@@ -569,7 +569,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
        error = mdc_mat_read_image_subheader(fp, startblk-1, &ish);
        if (error) return("ECAT6 Bad read image subheader");
-       if (MDC_INFO) { 
+       if (MDC_INFO) {
         MdcPrintLine('-',MDC_FULL_LENGTH);
         MdcPrntScrn("IMAGE SUBHEADER %05d:  ",img+1);
         MdcPrntScrn("Frame: %d  Plane: %d  Gate: %d  Data: %d  Bed: %d\n"
@@ -598,9 +598,9 @@ const char *MdcReadECAT6(FILEINFO *fi)
         MdcPrntScrn("Recon Start Hour   : %d\n",ish.recon_start_hour);
         MdcPrntScrn("Recon Start Minute : %d\n",ish.recon_start_minute);
         MdcPrntScrn("Recon Start Second : %d\n",ish.recon_start_sec);
-        MdcPrntScrn("Gate Duration      : %d [ms]\n",ish.gate_duration); 
+        MdcPrntScrn("Gate Duration      : %d [ms]\n",ish.gate_duration);
         MdcPrntScrn("Filter code        : %d ",ish.filter_code);
-        ish.filter_code = abs(ish.filter_code); 
+        ish.filter_code = abs(ish.filter_code);
         if ((ish.filter_code > -1) && (ish.filter_code < 7))
           MdcPrntScrn("(= %s)\n",MdcEcatFilterTypes[ish.filter_code]);
         else
@@ -675,7 +675,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
      /*  case  SUN_I2   : */
          case  VAX_I2   :  id->bits =16; id->type = BIT16_S; break;
          case  M68K_I4  :
-     /*  case  SUN_I4   : */ 
+     /*  case  SUN_I4   : */
          case  VAX_I4   :  id->bits =32; id->type = BIT32_S; break;
          case  IEEE_R4  :
      /*  case  SUN_R4   : */
@@ -686,13 +686,13 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
        if ( (strncmp(mh.user_process_code,"COR",10)==0) ||
             (strncmp(mh.user_process_code,"SAG",10)==0)) {
-         /* CORONAL SLICES  or SAGITTAL SLICES 
+         /* CORONAL SLICES  or SAGITTAL SLICES
             The images Ecat 6.4 software writes are useless:
             128x128 images with the small coronal/sagittal slice in it ...
             This means their pixel_xsize & pixel_ysize doesn't quite
-            fit the real world dimensions any more !! 
-            Therefore we don't even try to attempt writing the proper 
-            Acr/Nema variables ... 
+            fit the real world dimensions any more !!
+            Therefore we don't even try to attempt writing the proper
+            Acr/Nema variables ...
           */
        }else{ /* "TRA" or nothing */
          /* TRANSAXIAL SLICES (Transverse)             */
@@ -709,7 +709,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
 
          MdcFillImgPos(fi,img,(Uint32)(plane-1),slice_position);
          MdcFillImgOrient(fi,img);
-         
+
        }
 
        break;
@@ -749,9 +749,9 @@ const char *MdcReadECAT6(FILEINFO *fi)
                                                 ,ash.tilt_angle);
         MdcPrntScrn("Mu-Absorption Coefficient     : %f [1/cm]\n"
                                                 ,ash.attenuation_coeff);
-        MdcPrntScrn("Sample Distance               : %f [cm]\n" 
+        MdcPrntScrn("Sample Distance               : %f [cm]\n"
                                                 ,ash.sample_distance);
-       } 
+       }
 
        /* fill in IMG_DATA struct */
        id = &fi->image[img];
@@ -842,7 +842,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     bytes = id->width*id->height*MdcType2Bytes(id->type);
     bytes = MdcMatrixBlocks(bytes);
 
-    id->buf = MdcGetImgBuffer(bytes);   
+    id->buf = MdcGetImgBuffer(bytes);
     if (id->buf == NULL) return("ECAT6 Bad malloc image buffer");
 
     error = mdc_mat_read_matrix_data(fp,startblk,endblk,(Int16 *)id->buf);
@@ -854,7 +854,7 @@ const char *MdcReadECAT6(FILEINFO *fi)
     }
 
     if (fi->truncated) break;
-      
+
     img+=1;
   }
 
@@ -926,7 +926,7 @@ float MdcGetSliceLocation(FILEINFO *fi, Int32 img)
    switch (orient) {
      case MDC_TRANSAXIAL: /* z-coord */
         locat = fi->image[img].image_pos_pat[2];
-        break; 
+        break;
      case MDC_SAGITTAL  : /* x-coord */
         locat = fi->image[img].image_pos_pat[0];
         break;
@@ -945,7 +945,7 @@ int MdcGetFilterCode(char *string)
 {
   int i = 0;
 
-  for (i=0; i<MDC_MAX_ECATFLTRTYPES; i++) 
+  for (i=0; i<MDC_MAX_ECATFLTRTYPES; i++)
      if (strstr(string,MdcEcatFilterTypes[i]) != NULL) break;
 
   return(i);
@@ -990,7 +990,7 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   }
   if (fi->patient_weight == 0.) {
     mh->patient_weight[0] = '\0';
-  }else{ 
+  }else{
     sprintf(mh->patient_weight,"%.2f",fi->patient_weight);
   }
   sprintf(mh->patient_name,"%.31s",fi->patient_name);
@@ -998,15 +998,15 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
   sprintf(mh->operator_name,"%.31s",fi->operator_name);
   sprintf(mh->study_description,"%.31s",fi->study_descr);
   switch (fi->acquisition_type ) {
-    case MDC_ACQUISITION_STATIC : 
+    case MDC_ACQUISITION_STATIC :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_STATIC_EMISSION;  break;
-    case MDC_ACQUISITION_TOMO   :   
+    case MDC_ACQUISITION_TOMO   :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_STATIC_EMISSION;  break;
-    case MDC_ACQUISITION_DYNAMIC:   
+    case MDC_ACQUISITION_DYNAMIC:
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_DYNAMIC_EMISSION; break;
     case MDC_ACQUISITION_GSPECT :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_GATED_EMISSION;   break;
-    default                     : 
+    default                     :
         mh->acquisition_type = MDC_ECAT6_ACQTYPE_UNKNOWN;
 
   }
@@ -1015,7 +1015,7 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
 
   mh->num_planes = mh->num_frames = mh->num_gates = 1;
   mh->num_bed_pos = 1;
- 
+
   for ( i=3; i<=fi->dim[0]; i++) {
      switch (i) {
        case 3: mh->num_planes  = fi->dim[i];     break;
@@ -1034,13 +1034,13 @@ void MdcFillMainHeader(FILEINFO *fi, Mdc_Main_header *mh)
     mh->init_bed_position = fi->beddata[0].hoffset / 10.; /* cm */
     mh->bed_elevation     = fi->beddata[0].voffset / 10.; /* cm */
 
-    for (i=1; i<fi->bednr; i++) { 
-       if ( i==16 ) { 
+    for (i=1; i<fi->bednr; i++) {
+       if ( i==16 ) {
          MdcPrntWarn("ECAT6 Unsupported number of bed positions");
          break;
        }
        mh->bed_offset[i-1]  = fi->beddata[i].hoffset - fi->beddata[0].hoffset;
-       mh->bed_offset[i-1] /= 10.; /* cm */ 
+       mh->bed_offset[i-1] /= 10.; /* cm */
     }
   }else{
     /* guess bad offsets, assume adjacent bed positions */
@@ -1097,15 +1097,15 @@ void MdcFillImageSubHeader(FILEINFO *fi,Mdc_Image_subheader *ish
     ish->dimension_1 = id->width;
     ish->dimension_2 = id->height;
   }
-  ish->recon_scale = id->recon_scale; 
- 
+  ish->recon_scale = id->recon_scale;
+
   if (ish->data_type == 1 || ish->data_type == 2) {
     if (id->rescaled) {
       ish->image_min = (Int16) id->rescaled_min;
       ish->image_max = (Int16) id->rescaled_max;
     }else{
       ish->image_min = (Int16) id->min;
-      ish->image_max = (Int16) id->max; 
+      ish->image_max = (Int16) id->max;
     }
   }else{ /* data types too big for an Int16 */
     ish->image_min   = 0;
@@ -1130,14 +1130,14 @@ void MdcFillImageSubHeader(FILEINFO *fi,Mdc_Image_subheader *ish
   if (id->rescaled) {
     ish->quant_scale = id->rescaled_fctr;
     ish->ecat_calibration_fctr = 1.;
-  }else{  
+  }else{
     ish->quant_scale = id->quant_scale;
     ish->ecat_calibration_fctr = id->calibr_fctr;
   }
 
   if (strcmp(fi->recon_method,"Filtered Backprojection") == 0 ) {
     sprintf(ish->annotation,"%.39s",MDC_ECAT6_RECON_METHOD);
-  }else{ 
+  }else{
     sprintf(ish->annotation,"%.39s",fi->recon_method);
   }
 }
@@ -1147,12 +1147,12 @@ static void MdcResetSizes(FILEINFO *fi)
   fi->mwidth = saved_mwidth;
   fi->mheight= saved_mheight;
 }
- 
+
 const char *MdcWriteECAT6(FILEINFO *fi)
 {
   IMG_DATA *id;
   Mdc_Main_header mh;
-  Mdc_Image_subheader ish; 
+  Mdc_Image_subheader ish;
   Uint8 *buf, *maxbuf;
   Uint16 type, FREE;
   Int32 matnum, data=0, bed, gate, frame, plane, img=0;
@@ -1183,7 +1183,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
     if (MDC_FORCE_INT != BIT16_S) {
       MdcPrntWarn("ECAT6 Only Int16 pixels supported");
     }
-  } 
+  }
 
   /* check some integrities */
 
@@ -1251,7 +1251,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
      }
 
      matnum = mdc_mat_numcod(frame,plane,gate,data,bed);
-     MdcFillImageSubHeader(fi,&ish,type,img,matnum,NEWSIZE); 
+     MdcFillImageSubHeader(fi,&ish,type,img,matnum,NEWSIZE);
 
      if (fi->diff_size || NEWSIZE) {
        size = fi->mwidth * fi->mheight * MdcType2Bytes(type);
@@ -1262,7 +1262,7 @@ const char *MdcWriteECAT6(FILEINFO *fi)
          return("ECAT6 Bad malloc maxbuf");
        }
 
-       if (FREE) MdcFree(buf); 
+       if (FREE) MdcFree(buf);
 
        FREE=MDC_YES;
 
@@ -1270,8 +1270,8 @@ const char *MdcWriteECAT6(FILEINFO *fi)
         size = id->width * id->height * MdcType2Bytes(type);
         maxbuf = buf;
      }
- 
-     matnum = mdc_mat_numcod(frame,plane,gate,data,bed);  
+
+     matnum = mdc_mat_numcod(frame,plane,gate,data,bed);
      if (mdc_mat_write_image(fi->ofp,matnum,&ish,(Uint16 *)maxbuf,(Int32)size))
      {
        MdcResetSizes(fi);
