@@ -83,7 +83,7 @@
 #include "medcon.h"
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 #define largest_code    4095            /* largest possible code */
@@ -111,18 +111,18 @@ static Int16 free_code;
 int MdcCheckGIF(FILEINFO *fi)
 {
 
-  MDC_GIFHEADER gh; 
+  MDC_GIFHEADER gh;
 
   memset(&gh,0,MDC_GIF_GH_SIZE);
 
-  if ( fread((char *)&gh,1,MDC_GIF_GH_SIZE,fi->ifp) != MDC_GIF_GH_SIZE ) 
+  if ( fread((char *)&gh,1,MDC_GIF_GH_SIZE,fi->ifp) != MDC_GIF_GH_SIZE )
     return(MDC_BAD_READ);
-  if ( memcmp(gh.sig,MDC_GIF_SIG,3) ) 
+  if ( memcmp(gh.sig,MDC_GIF_SIG,3) )
     return(MDC_FRMT_NONE);
 
   return(MDC_FRMT_GIF);
-} 
-  
+}
+
 /* unpack a GIF file */
 char *MdcReadGIF(FILEINFO *fi)
 {
@@ -160,7 +160,7 @@ char *MdcReadGIF(FILEINFO *fi)
 
   fi->bits=8; /* (gh.flags & 0x0007) + 1; */
 
-  if (MDC_INFO) { 
+  if (MDC_INFO) {
     MdcPrntScrn("signature: %.6s\n",gh.sig);
     MdcPrntScrn("screen width: %d\nscreen height: %d\n",
                           gh.screenwidth,gh.screenheight);
@@ -171,9 +171,9 @@ char *MdcReadGIF(FILEINFO *fi)
   if (gh.flags & 0x80) {
     if (fi->map < 2) fi->map=MDC_MAP_PRESENT;
     c = 3 * (1 << ((gh.flags & 0x0007) + 1));
-    if (fread(fi->palette,1,c,fp) != c) 
+    if (fread(fi->palette,1,c,fp) != c)
       return("GIF  Bad read global palette");
- 
+
     if (MDC_INFO) {
       MdcPrntScrn("Yes\n");
       MdcPrntScrn("bits: %hd\n",(gh.flags & 7)+1 );
@@ -184,7 +184,7 @@ char *MdcReadGIF(FILEINFO *fi)
       MdcPrntScrn("background: %hd\n", (int)gh.background);
       MdcPrntScrn("aspect: %hd\n\n",(int)gh.aspect);
     }
-   
+
   } else if (MDC_INFO) MdcPrntScrn("No\n");
 
   /* step through the blocks */
@@ -194,7 +194,7 @@ char *MdcReadGIF(FILEINFO *fi)
     if (c == ',') {
 
       if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_SET,0.0,NULL);
- 
+
       if (MDC_INFO) {
         MdcPrntScrn("\n");
         MdcPrintLine('=',MDC_HALF_LENGTH);
@@ -210,7 +210,7 @@ char *MdcReadGIF(FILEINFO *fi)
       number+=1;
 
       if (!MdcGetStructID(fi,number)) return("GIF  Bad malloc IMG_DATA struct");
-       
+
       /* fill in the IMG_DATA struct */
       fi->image[img].width=(Uint32) iblk.width;
       fi->image[img].height=(Uint32) iblk.height;
@@ -233,9 +233,9 @@ char *MdcReadGIF(FILEINFO *fi)
           MdcPrntScrn("sorted: ");
           if ( iblk.flags & 0x0020 ) MdcPrntScrn("Yes\n");
           else MdcPrntScrn("No\n");
-        }           
+        }
         b = 3*(1<<((iblk.flags & 0x0007) + 1));
-        if (fread(fi->palette,1,b,fp) != b) 
+        if (fread(fi->palette,1,b,fp) != b)
           return("GIF  Bad read local palette");
       } else if (MDC_INFO) MdcPrntScrn("No\n");
 
@@ -246,9 +246,9 @@ char *MdcReadGIF(FILEINFO *fi)
       fi->image[img].flags = iblk.flags;
 
       /* get an image buffer */
-      
+
       bytes=MdcPixels2Bytes(fi->image[img].width*fi->image[img].height*8);
-          
+
       if ( (fi->image[img].buf=MdcGetImgBuffer(bytes)) == NULL )
         return("GIF  Bad malloc image buffer");
 
@@ -273,7 +273,7 @@ char *MdcReadGIF(FILEINFO *fi)
         break;
       }
 
-    }else if (c == '!') MdcDoExtension(fi);  
+    }else if (c == '!') MdcDoExtension(fi);
 
   }
 
@@ -299,14 +299,14 @@ void MdcDoExtension(FILEINFO *fi)
   memset(&ap,0,MDC_GIF_ABLK_SIZE);
 
   if (MDC_INFO) { MdcPrntScrn("\n"); MdcPrintLine('=',MDC_HALF_LENGTH); }
- 
+
   switch (c=(Int16)fgetc(fp)) {
 
-   case 0x0001:		/* plain text descriptor */
+   case 0x0001: /* plain text descriptor */
     if (MdcReadGifPlainTextBlk(fp,&pt) == MDC_YES) {
 
-      if (MDC_INFO) { 
-        MdcPrntScrn("\nPLAIN TEXT BLOCK\n"); 
+      if (MDC_INFO) {
+        MdcPrntScrn("\nPLAIN TEXT BLOCK\n");
           MdcPrintLine('-', MDC_HALF_LENGTH);
         MdcPrntScrn("This block requires %u bytes\n",pt.blocksize);
         MdcPrntScrn("Text location at (%u,%u)\n",pt.left,pt.top);
@@ -318,61 +318,61 @@ void MdcDoExtension(FILEINFO *fi)
         MdcPrntScrn("Background colour is %u\n",pt.backcolour);
       }
       do {
-	if ((n=(Int16)fgetc(fp)) != EOF) {
-	  for (i=0;i<n;++i) {
-             c = (Int16)fgetc(fp); 
+        if ((n=(Int16)fgetc(fp)) != EOF) {
+          for (i=0;i<n;++i) {
+             c = (Int16)fgetc(fp);
              if (MDC_INFO) MdcPrintChar(c);
           }
-	}
+        }
       }while (n > 0 && n != EOF);
     }else{
       MdcPrntWarn("GIF  Bad read plain text block");
     }
     break;
 
-   case 0x00f9:		/* graphic control block */
+   case 0x00f9: /* graphic control block */
     if (MdcReadGifControlBlk(fp,&cb) == MDC_YES) {
 
       if (MDC_INFO) {
         MdcPrntScrn("\nCONTROL BLOCK\n"); MdcPrintLine('-',MDC_HALF_LENGTH);
         MdcPrntScrn("This block requires %u bytes\n",cb.blocksize);
         switch((cb.flags >> 2) & 0x0007) {
-	  case 0:
-	    MdcPrntScrn("No disposal specified\n");
-	    break;
-	  case 1:
-	    MdcPrntScrn("Do not dispose\n");
-	    break;
-	  case 2:
-	    MdcPrntScrn("Dispose to background colour\n");
-	    break;
-	  case 3:
-	    MdcPrntScrn("Dispose to previous graphic\n");
-	    break;
-	  default:
-	    MdcPrntScrn("Unknown disposal procedure\n");
-	    break;
+          case 0:
+            MdcPrntScrn("No disposal specified\n");
+            break;
+          case 1:
+            MdcPrntScrn("Do not dispose\n");
+            break;
+          case 2:
+            MdcPrntScrn("Dispose to background colour\n");
+            break;
+          case 3:
+            MdcPrntScrn("Dispose to previous graphic\n");
+            break;
+          default:
+            MdcPrntScrn("Unknown disposal procedure\n");
+            break;
         }
         if (cb.flags & 0x0002)
-	  MdcPrntScrn("User input required - delay for %g seconds\n"
+          MdcPrntScrn("User input required - delay for %g seconds\n"
                                       ,(float)cb.delay/100.);
         else
-	  MdcPrntScrn("No user input required\n");
+          MdcPrntScrn("No user input required\n");
 
         if (cb.flags & 0x0001)
-	  MdcPrntScrn("Transparent colour: %u\n",cb.transparent_colour);
+          MdcPrntScrn("Transparent colour: %u\n",cb.transparent_colour);
         else
-	  MdcPrntScrn("No transparent_colour\n");
+          MdcPrntScrn("No transparent_colour\n");
       }
-    }else{ 
+    }else{
       MdcPrntWarn("GIF  Bad read control block");
     }
     break;
 
-   case 0x00fe:		/* comment extension */
-      
-    if (MDC_INFO) { 
-      MdcPrntScrn("\nCOMMENT BLOCK\n"); MdcPrintLine('-',MDC_HALF_LENGTH); 
+   case 0x00fe: /* comment extension */
+
+    if (MDC_INFO) {
+      MdcPrntScrn("\nCOMMENT BLOCK\n"); MdcPrintLine('-',MDC_HALF_LENGTH);
     }
     do {
       if ((n=(Int16)fgetc(fp)) != EOF) {
@@ -381,23 +381,23 @@ void MdcDoExtension(FILEINFO *fi)
           if (fi->comment == NULL) {
             MdcPrntWarn("Couldn't allocate comment buffer");
           }else if (fi->comm_length==0) fi->comment[fi->comm_length] = '\0';
-        } 
-	for (i=0;i<n;++i) {
+        }
+        for (i=0;i<n;++i) {
            c = (Int16)fgetc(fp);
-           if (MDC_INFO) MdcPrintChar(c); 
+           if (MDC_INFO) MdcPrintChar(c);
            if (fi->comment != NULL) {
              fi->comment[fi->comm_length++] = c;
            }
-        } 
+        }
         if ((n <= 0) && (fi->comment !=  NULL)) {
           fi->comment[fi->comm_length++] = '\n';
           fi->comment[fi->comm_length]   = '\0';
         }
       }
-    }while (n > 0 && n != EOF); 
+    }while (n > 0 && n != EOF);
     break;
 
-   case 0x00ff:		/* application extension */
+   case 0x00ff: /* application extension */
     if (MdcReadGifApplicationBlk(fp,&ap) == MDC_YES) {
       if (MDC_INFO) {
         MdcPrntScrn("\nAPPLICATION BLOCK\n"); MdcPrintLine('-',MDC_HALF_LENGTH);
@@ -408,18 +408,18 @@ void MdcDoExtension(FILEINFO *fi)
       do {
         if ((n=(Int16)fgetc(fp)) != EOF) {
           if (MDC_INFO) MdcPrntScrn("\nSub-block requires %d bytes:\n",n);
-	  for (i=0;i<n;++i) {
-             c = (Int16)fgetc(fp); 
+          for (i=0;i<n;++i) {
+             c = (Int16)fgetc(fp);
              if (MDC_INFO) MdcPrintChar(c);
           }
-	}
+        }
       }while (n > 0 && n != EOF);
     }else{
       MdcPrntWarn("GIF  Bad read application block");
     }
     break;
 
-   default:		/* something else */
+   default: /* something else */
     MdcPrntWarn("GIF  Unknown extension 0x%02.2x\n",c & 0x00ff);
     n=(Int16)fgetc(fp);
     for (i=0;i<n;++i) fgetc(fp);
@@ -440,7 +440,7 @@ int MdcReadGifHeader(FILE *fp, MDC_GIFHEADER *gh)
   gh->flags      = (Uint8) bb[10];
   gh->background = (Uint8) bb[11];
   gh->aspect     = (Uint8) bb[12];
-  
+
   return(MDC_YES);
 }
 
@@ -455,7 +455,7 @@ int MdcReadGifImageBlk(FILE *fp, MDC_GIFIMAGEBLOCK *ib)
   memcpy(&ib->width ,bb+4,2); MdcSWAP(ib->width);
   memcpy(&ib->height,bb+6,2); MdcSWAP(ib->height);
   ib->flags = (Uint8) bb[8];
- 
+
   return(MDC_YES);
 }
 
@@ -489,7 +489,7 @@ int MdcReadGifPlainTextBlk(FILE *fp, MDC_GIFPLAINTEXT *pt)
   pt->cellheight = (Uint8) bb[10];
   pt->forecolour = (Uint8) bb[11];
   pt->backcolour = (Uint8) bb[12];
-  
+
   return(MDC_YES);
 }
 
@@ -502,7 +502,7 @@ int MdcReadGifApplicationBlk(FILE *fp, MDC_GIFAPPLICATION *ap)
   ap->blocksize = (Uint8) bb[0];
   memcpy(ap->applstring    ,bb+1,8);
   memcpy(ap->authentication,bb+9,3);
-  
+
   return(MDC_YES);
 }
 
@@ -538,11 +538,12 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
   static Uint8 lastcodestack[4096];   /* Statck for previous code */
   static Int16 codestack[4096];      /* Stack for links */
 
-  static Int16 wordmasktable[] = { 0x0000,0x0001,0x0003,0x0007,
-				 0x000f,0x001f,0x003f,0x007f,
-				 0x00ff,0x01ff,0x03ff,0x07ff,
-				 0x0fff,0x1fff,0x3fff,0x7fff
-			     };
+  static Int16 wordmasktable[] = {
+    0x0000,0x0001,0x0003,0x0007,
+    0x000f,0x001f,0x003f,0x007f,
+    0x00ff,0x01ff,0x03ff,0x07ff,
+    0x0fff,0x1fff,0x3fff,0x7fff
+  };
 
   static Int16 inctable[] = { 8,8,4,2,0 };   /* interlace increments */
   static Int16 startable[] = { 0,4,2,1,0 };  /* interlace starts */
@@ -556,16 +557,16 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
   codesize2 = 1 << (codesize = bits + 1);
   oldcode=oldtoken=MDC_NO_CODE;
 
-  if ((linebuffer=(Uint8 *)malloc(id->width)) == NULL) 
+  if ((linebuffer=(Uint8 *)malloc(id->width)) == NULL)
     return("GIF  Bad malloc linebuffer");
 
   /* loop until something breaks */
   for (;;) {
     if (bitsleft==8) {
       if (++p >= q && (((blocksize = (Int16)fgetc(fp)) < 1) ||
-	   (q=(p=b)+fread(b,1,(unsigned)blocksize,fp))< (b+blocksize))) {
-	MdcFree(linebuffer);
-	return("GIF  Unexpected EOF (1)");
+            (q=(p=b)+fread(b,1,(unsigned)blocksize,fp))< (b+blocksize))) {
+        MdcFree(linebuffer);
+        return("GIF  Unexpected EOF (1)");
       }
       bitsleft = 0;
     }
@@ -576,26 +577,26 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
 
     }else {
       if (++p >= q && (((blocksize = (Int16)fgetc(fp)) < 1) ||
-	   (q=(p=b)+fread(b,1,(unsigned)blocksize,fp)) < (b+blocksize))) {
-	MdcFree(linebuffer);
-	return("GIF  Unexpected EOF (2)");
+            (q=(p=b)+fread(b,1,(unsigned)blocksize,fp)) < (b+blocksize))) {
+        MdcFree(linebuffer);
+        return("GIF  Unexpected EOF (2)");
       }
       thiscode |= *p << (8 - bitsleft);
       if (currentcode <= 16) *p >>= (bitsleft=currentcode-8);
       else {
-	  if (++p >= q && (((blocksize = (Int16)fgetc(fp)) < 1) ||
-	       (q=(p=b) + fread(b,1,(unsigned)blocksize,fp)) < (b+blocksize))) {
-	    MdcFree(linebuffer);
-	    return("GIF  Unexpected EOF (3)");
-	  }
-	  thiscode |= *p << (16 - bitsleft);
-	  *p >>= (bitsleft = currentcode - 16);
+        if (++p >= q && (((blocksize = (Int16)fgetc(fp)) < 1) ||
+              (q=(p=b) + fread(b,1,(unsigned)blocksize,fp)) < (b+blocksize))) {
+          MdcFree(linebuffer);
+          return("GIF  Unexpected EOF (3)");
+        }
+        thiscode |= *p << (16 - bitsleft);
+        *p >>= (bitsleft = currentcode - 16);
       }
     }
     thiscode &= wordmasktable[codesize];
     currentcode = thiscode;
 
-    if (thiscode == (bits2+1)) break;	/* found EOI */
+    if (thiscode == (bits2+1)) break; /* found EOI */
     if (thiscode > nextcode) {
       MdcFree(linebuffer);
       return("GIF  Bad compression code");
@@ -612,8 +613,8 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
 
     if (thiscode==nextcode) {
       if (oldcode==MDC_NO_CODE) {
-	MdcFree(linebuffer);
-	return("GIF  Bad first code");
+        MdcFree(linebuffer);
+        return("GIF  Bad first code");
       }
       *u++ = oldtoken;
       thiscode = oldcode;
@@ -632,14 +633,14 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
 
       linebuffer[nxtbyte++]=pix;
       if (nxtbyte >= id->width) {
-	MdcPutGifLine(id,linebuffer,line);
-	nxtbyte=0;
+        MdcPutGifLine(id,linebuffer,line);
+        nxtbyte=0;
 
-	/* check for interlaced image */
-	if (id->flags & 0x40) {
-	  line+=inctable[pass];
-	  if (line >= id->height) line=startable[++pass];
-	}else ++line;
+        /* check for interlaced image */
+        if (id->flags & 0x40) {
+          line+=inctable[pass];
+          if (line >= id->height) line=startable[++pass];
+        }else ++line;
       }
 
       if (u <= firstcodestack) break;
@@ -651,7 +652,7 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
       codestack[nextcode] = oldcode;
       lastcodestack[nextcode] = oldtoken;
       if (++nextcode >= codesize2 && codesize < 12)
-	codesize2 = 1 << ++codesize;
+        codesize2 = 1 << ++codesize;
     }
     oldcode = currentcode;
   }
@@ -663,10 +664,10 @@ char *MdcUnpackImage(FILEINFO *fi, Uint32 nr )
 /* save one line to memory */
 void MdcPutGifLine(IMG_DATA *id, Uint8 *p, Int16 n)
 {
-  
+
   if ( n >= 0  && n < id->height )
     memcpy(id->buf+((Uint32)n*id->width),p,id->width);
-} 
+}
 
 char *MdcWriteGIF(FILEINFO *fi)
 {
@@ -702,7 +703,7 @@ char *MdcWriteGIF(FILEINFO *fi)
   }else{
     if (MdcKeepFile(fi->ofname))
       return("GIF  File exists!!");
-    if ( (fi->ofp=fopen(fi->ofname,"wb")) == NULL ) 
+    if ( (fi->ofp=fopen(fi->ofname,"wb")) == NULL )
       return ("GIF  Couldn't open file");
   }
 
@@ -710,26 +711,26 @@ char *MdcWriteGIF(FILEINFO *fi)
     if (MDC_FORCE_INT != BIT8_U) {
       MdcPrntWarn("GIF  Only Uint8 pixels supported");
     }
-  } 
+  }
 
   /* check supported things */
   if (MDC_QUANTIFY || MDC_CALIBRATE) {
     MdcPrntWarn("GIF  Normalization loses quantified values!");
   }
 
-  if ( MdcWriteGifHeader(fi,&opt) ) 
+  if ( MdcWriteGifHeader(fi,&opt) )
     return("GIF  Bad write screen description");
 
   if ( MdcWriteCommentBlock(fi,MDC_LIBVERS) )
      return("GIF  Bad write comment block");
 
-  if ( fi->acquisition_type != MDC_ACQUISITION_UNKNOWN ) 
+  if ( fi->acquisition_type != MDC_ACQUISITION_UNKNOWN )
   if ( MdcMakeScanInfoStr(fi) ) {
     if ( MdcWriteCommentBlock(fi,mdcbufr) ) {
       return("GIF  Bad write scan info comment block");
     }
   }
- 
+
   if ( (fi->number > 1) && (opt.loop == MDC_YES) ) {
     if ( MdcWriteLoopBlock(fi,"NETSCAPE","2.0") )
       return ("GIF  Bad write loop block");
@@ -739,27 +740,27 @@ char *MdcWriteGIF(FILEINFO *fi)
 
      if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_INCR,1./(float)fi->number,NULL);
 
-     if ( (fi->number > 1) || (opt.transp == MDC_YES)) 
-       if ( MdcWriteControlBlock(fi,&opt,nr) ) 
+     if ( (fi->number > 1) || (opt.transp == MDC_YES))
+       if ( MdcWriteControlBlock(fi,&opt,nr) )
          return("GIF  Bad write control block");
 
      if ( MdcWriteImageBlock(fi,nr) )  return("GIF  Bad write image block");
 
      if (fi->image[nr].type != BIT8_U) {
-        if ( (buf8=MdcGetImgBIT8_U(fi, nr)) == NULL) 
+        if ( (buf8=MdcGetImgBIT8_U(fi, nr)) == NULL)
           return("GIF  Bad malloc new image buffer");
-        if ( MdcWriteImage(buf8,fi,nr) ) { 
+        if ( MdcWriteImage(buf8,fi,nr) ) {
           MdcFree(buf8);  return("GIF  Bad compression (1)");
         }else{
           MdcFree(buf8);
         }
      }else{
-        if ( MdcWriteImage(fi->image[nr].buf,fi,nr) ) 
+        if ( MdcWriteImage(fi->image[nr].buf,fi,nr) )
           return("GIF  Bad compression (2)");
-     } 
+     }
   }
 
-  if ( MdcWriteApplicationBlock(fi,MDC_PRGR,"NLF")) 
+  if ( MdcWriteApplicationBlock(fi,MDC_PRGR,"NLF"))
     return("GIF  Bad write application block");
 
   if ( fputc(';',fi->ofp) == EOF ) return("GIF  Bad write terminator code");
@@ -768,7 +769,7 @@ char *MdcWriteGIF(FILEINFO *fi)
 
   return NULL;
 
-}  
+}
 
 void MdcGetGifOpt(FILEINFO *fi, MDC_GIFOPT *opt)
 {
@@ -791,14 +792,14 @@ void MdcGetGifOpt(FILEINFO *fi, MDC_GIFOPT *opt)
 
  if (!MdcPutDefault(mdcbufr)) {
    fi->map = (Uint8)atoi(mdcbufr);
-   MdcGetColorMap((int)fi->map,fi->palette); 
+   MdcGetColorMap((int)fi->map,fi->palette);
  }
 
  if (fi->number > 1) {
    MdcPrntScrn("\n\tInsert a display loop    [yes]? ");
    mdcbufr[0]='y';
    if (!MdcPutDefault(mdcbufr))
-     if (mdcbufr[0]=='n' || mdcbufr[0]=='N') opt->loop = MDC_NO; 
+     if (mdcbufr[0]=='n' || mdcbufr[0]=='N') opt->loop = MDC_NO;
    MdcPrntScrn("\n\tDelay 1/100ths of a second [%3d]? ", GIF_DELAY);
    if (!MdcPutDefault(mdcbufr)) {
      opt->delay = (Uint16)atoi(mdcbufr);
@@ -840,10 +841,10 @@ int MdcWriteGifHeader(FILEINFO *fi, MDC_GIFOPT *opt)
     gh.flags=(((bits-1) & 0x07)<<4);
   }else{
     gh.flags = (0x80 | ((bits-1)<<4) | ((bits-1) & 0x07));
-  } 
+  }
 
   MdcSWAP(gh.screenwidth); MdcSWAP(gh.screenheight);
- 
+
   /* write the header */
   fwrite((char *)&gh,1,MDC_GIF_GH_SIZE,fi->ofp);
 
@@ -862,14 +863,14 @@ int MdcWriteControlBlock(FILEINFO *fi, MDC_GIFOPT *opt, Uint32 n)
 
   fputc('!',fi->ofp);             /* say it's an extension block */
   fputc(0xf9,fi->ofp);            /* say it's a control block    */
- 
+
   cb.blocksize=0x04;
   cb.flags=0x00;
 
   if (fi->number > 1 ) {
     cb.flags^=0x02; cb.flags<<=2; /* dispose to background       */
     cb.flags^=0x02;               /* wait for user input         */
-    cb.delay = opt->delay;        /* delay to dispose 1/100 sec  */ 
+    cb.delay = opt->delay;        /* delay to dispose 1/100 sec  */
   }
   if (opt->transp == MDC_YES) {   /* transparent color           */
     cb.flags^=0x01;
@@ -904,7 +905,7 @@ int MdcWriteImageBlock(FILEINFO *fi, Uint32 n)
   if(palette==NULL) ib.flags=bits-1;
   else ib.flags=((bits-1) & 0x07) | 0x80;
 
-  MdcSWAP(ib.left);  MdcSWAP(ib.top); 
+  MdcSWAP(ib.left);  MdcSWAP(ib.top);
   MdcSWAP(ib.width); MdcSWAP(ib.height);
 
   /* write the block */
@@ -916,14 +917,14 @@ int MdcWriteImageBlock(FILEINFO *fi, Uint32 n)
 
 /* compress an image */
 int MdcWriteImage(Uint8 * buffer, FILEINFO *fi, Uint32 n)
-{ 
+{
   FILE *fp=fi->ofp;
   Uint8 *pix=buffer;
   Int16 prefix_code;
   Int16 suffix_char;
   Int16 hx,d;
   Uint16 min_code_size=8;
-  Uint32 i, width=fi->image[n].width, height=fi->image[n].height; 
+  Uint32 i, width=fi->image[n].width, height=fi->image[n].height;
 
 
   /* make sure the initial code size is legal */
@@ -953,7 +954,7 @@ int MdcWriteImage(Uint8 * buffer, FILEINFO *fi, Uint32 n)
 
     if ( i == (width*height) ) break;
 
-    suffix_char = (Int16)pix[i]; 
+    suffix_char = (Int16)pix[i];
 
     /* derive an index into the code table */
     hx=(prefix_code ^ (suffix_char << 5)) % table_size;
@@ -1018,7 +1019,7 @@ int MdcWriteImage(Uint8 * buffer, FILEINFO *fi, Uint32 n)
 int MdcWriteCommentBlock(FILEINFO *fi, const char *comment)
 {
         int n;
-       
+
         n=strlen(comment);
 
         fputc('!',fi->ofp);          /* say it's an extension block */
@@ -1067,8 +1068,8 @@ int MdcWriteLoopBlock(FILEINFO *fi, const char *applstr, const char *auth)
 
   return(ferror(fi->ofp));
 }
-   
-  
+
+
 int MdcWriteApplicationBlock(FILEINFO *fi, const char *applstr, const char *auth)
 {
   MDC_GIFAPPLICATION ap;
